@@ -1,5 +1,5 @@
 package Dancer2;
-$Dancer2::VERSION = '0.207000';
+$Dancer2::VERSION = '0.208000';
 # ABSTRACT: Lightweight yet powerful web application framework
 
 use strict;
@@ -128,7 +128,7 @@ Dancer2 - Lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 0.207000
+version 0.208000
 
 =head1 DESCRIPTION
 
@@ -313,6 +313,7 @@ We are also on IRC: #dancer on irc.perl.org.
     Jean Stebens
     Jens Rehsack
     Joel Berger
+    Johannes Piehler
     Jonathan Cast
     Jonathan Scott Duff
     Joseph Frazer
@@ -373,6 +374,7 @@ We are also on IRC: #dancer on irc.perl.org.
     Victor Adam
     Vince Willems
     Vincent Bachelier
+    xenu
     Yves Orton
 
 =head1 AUTHOR
@@ -381,7 +383,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alexis Sukrieh.
+This software is copyright (c) 2019 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
