@@ -1,8 +1,7 @@
 package Dancer2::CLI;
 # ABSTRACT: Dancer2 cli application
-$Dancer2::CLI::VERSION = '0.206000_02'; # TRIAL
-
-$Dancer2::CLI::VERSION = '0.20600002';use strict;
+$Dancer2::CLI::VERSION = '0.208000';
+use strict;
 use warnings;
 use App::Cmd::Setup -app;
 
@@ -20,7 +19,7 @@ Dancer2::CLI - Dancer2 cli application
 
 =head1 VERSION
 
-version 0.206000_02
+version 0.208000
 
 =head1 AUTHOR
 
@@ -28,7 +27,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alexis Sukrieh.
+This software is copyright (c) 2019 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
