@@ -1,8 +1,7 @@
 package Dancer2::Core::Role::Engine;
 # ABSTRACT: Role for engines
-$Dancer2::Core::Role::Engine::VERSION = '0.206000_02'; # TRIAL
-
-$Dancer2::Core::Role::Engine::VERSION = '0.20600002';use Moo::Role;
+$Dancer2::Core::Role::Engine::VERSION = '0.208000';
+use Moo::Role;
 use Dancer2::Core::Types;
 
 with 'Dancer2::Core::Role::Hookable';
@@ -43,7 +42,7 @@ Dancer2::Core::Role::Engine - Role for engines
 
 =head1 VERSION
 
-version 0.206000_02
+version 0.208000
 
 =head1 DESCRIPTION
 
@@ -64,7 +63,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alexis Sukrieh.
+This software is copyright (c) 2019 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
